takeFrom method
Copies all data from source into target. Used when you want to maintain a reference to target,
but want to inject new values from source
Implementation
void takeFrom(V source, V target) => illegalState("Not implemented");
Copies all data from source into target. Used when you want to maintain a reference to target,
but want to inject new values from source
void takeFrom(V source, V target) => illegalState("Not implemented");